pilas.asistente_base

Package pilas :: Module asistente_base |
[hide private]
[frames] | no frames]

# Source Code for Module pilas.asistente_base

     1  # -*- coding: utf-8 -*-
     2
     3  # Form implementation generated from reading ui file 'asistente.ui'
     4  #
     5  # Created: Fri Nov  2 01:12:59 2012
     6  #      by: PyQt4 UI code generator 4.9.1
     7  #
     8  # WARNING! All changes made in this file will be lost!
     9
    10  from PyQt4 import QtCore, QtGui
    11
    12  try:
    13      _fromUtf8 = QtCore.QString.fromUtf8
    14  except AttributeError:
    15      _fromUtf8 = lambda s: s
    16
    17 -class Ui_AsistenteWindow(object):
    18 -    def setupUi(self, AsistenteWindow):
    19          AsistenteWindow.setObjectName(_fromUtf8("AsistenteWindow"))
    20          AsistenteWindow.resize(507, 342)
    21          icon = QtGui.QIcon()
    22          icon.addPixmap(QtGui.QPixmap(_fromUtf8("pilas.ico")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
    23          AsistenteWindow.setWindowIcon(icon)
    24          self.centralwidget = QtGui.QWidget(AsistenteWindow)
    25          self.centralwidget.setObjectName(_fromUtf8("centralwidget"))
    26          self.gridLayout = QtGui.QGridLayout(self.centralwidget)
    27          self.gridLayout.setMargin(0)
    28          self.gridLayout.setObjectName(_fromUtf8("gridLayout"))
    29          self.webView = QtWebKit.QWebView(self.centralwidget)
    30          self.webView.setUrl(QtCore.QUrl(_fromUtf8("about:blank")))
    31          self.webView.setObjectName(_fromUtf8("webView"))
    32          self.gridLayout.addWidget(self.webView, 0, 0, 1, 1)
    33          AsistenteWindow.setCentralWidget(self.centralwidget)
    34          self.menubar = QtGui.QMenuBar(AsistenteWindow)
    35          self.menubar.setGeometry(QtCore.QRect(0, 0, 507, 22))
    36          self.menubar.setObjectName(_fromUtf8("menubar"))
    37          self.menu_Archivo = QtGui.QMenu(self.menubar)
    38          self.menu_Archivo.setObjectName(_fromUtf8("menu_Archivo"))
    39          AsistenteWindow.setMenuBar(self.menubar)
    40          self.statusbar = QtGui.QStatusBar(AsistenteWindow)
    41          self.statusbar.setObjectName(_fromUtf8("statusbar"))
    42          AsistenteWindow.setStatusBar(self.statusbar)
    43          self.salir_action = QtGui.QAction(AsistenteWindow)
    44          self.salir_action.setObjectName(_fromUtf8("salir_action"))
    45          self.menu_Archivo.addSeparator()
    46          self.menu_Archivo.addAction(self.salir_action)
    47          self.menubar.addAction(self.menu_Archivo.menuAction())
    48
    49          self.retranslateUi(AsistenteWindow)
    50          QtCore.QMetaObject.connectSlotsByName(AsistenteWindow)
    51
    52 -    def retranslateUi(self, AsistenteWindow):
    53          AsistenteWindow.setWindowTitle(QtGui.QApplication.translate("AsistenteWindow", "pilas-engine", None, QtGui.QApplication.UnicodeUTF8))
    54          self.menu_Archivo.setTitle(QtGui.QApplication.translate("AsistenteWindow", "&Archivo", None, QtGui.QApplication.UnicodeUTF8))
    55          self.salir_action.setText(QtGui.QApplication.translate("AsistenteWindow", "Salir", None, QtGui.QApplication.UnicodeUTF8))
    56
    57  from PyQt4 import QtWebKit
    58
    59  if __name__ == "__main__":
    60      import sys
    61      app = QtGui.QApplication(sys.argv)
    62      AsistenteWindow = QtGui.QMainWindow()
    63      ui = Ui_AsistenteWindow()
    64      ui.setupUi(AsistenteWindow)
    65      AsistenteWindow.show()
    66      sys.exit(app.exec_())
    67